@@ -20,17 +20,23 @@ class SendDataController:
                 self.returnData = self.geochat_sending(clientInformationQueue, processedCoT, sender, shareDataPipe)
                 return self.returnData
             elif sender == processedCoT:
-                for client in clientInformationQueue:
+                for user_id, client in clientInformationQueue.items():
                     try:
-                        sock = client.socket
-                        sock.send(processedCoT.idData.encode())
-                        sender.socket.send(client.idData.encode())
-                        # this is a special case which is identified
-                        # by the server due to the list contents
-                        # being within a list
+                        if user_id != processedCoT.modelObject.uid:
+                            user = client[1]
+                            sock = client[0]
+
+                            # send new client data to existing clients
+                            sock.send(processedCoT.idData.encode())
+
+                            # send existing client data to new client
+                            print(user.m_presence.xmlString.encode())
+                            sender.socket.send(user.m_presence.xmlString.encode())
+                            # this is a special case which is identified
+                            # by the server due to the list contents
+                            # being within a list
                     except Exception as e:
                         logger.error('error in sending connection data ' + str(processedCoT.idData))
-                        pass
                 copiedProcessedCoTObject = copy.deepcopy(processedCoT)
                 copiedProcessedCoTObject.idData = copiedProcessedCoTObject.idData.encode()
                 shareDataPipe.put([copiedProcessedCoTObject])
@@ -55,16 +61,16 @@ class SendDataController:
                 # print('marti present')
                 for dest in processedCoT.modelObject.detail.marti.dest:
                     try:
-                        for client in clientInformationQueue:
-                            if client.modelObject.detail.contact.callsign == dest.callsign:
+                        for client in clientInformationQueue.values():
+                            if client[1].m_presence.modelObject.detail.contact.callsign == dest.callsign:
                                 print('client socket is ' + str(client.socket))
-                                sock = client.socket
+                                sock = client[0]
                                 try:
                                     sock.send(processedCoT.xmlString)
                                 except Exception as e:
                                     logger.error('error sending data with marti to client data ' + str(
                                         processedCoT.xmlString) + 'error is ' + str(e))
-                                    return (-1, client)
+                                    return (-1, client[1])
                             else:
                                 continue
                     except Exception as e:
@@ -82,8 +88,8 @@ class SendDataController:
             return -1
     def send_to_all(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
-            for client in clientInformationQueue:
-                sock = client.socket
+            for client in clientInformationQueue.values():
+                sock = client[0]
                 try:
                     if hasattr(processedCoT, 'xmlString'):
                         # print('sending to all ' + str(processedCoT.xmlString))
@@ -98,7 +104,7 @@ class SendDataController:
                             sock.send(processedCoT.idData.encode())
                 except Exception as e:
                     logger.error('error in sending of data ' + str(e))
-                    return (-1, client)
+                    return (-1, client[1])
             if shareDataPipe != None:
                 processedCoT.clientInformation = None
                 shareDataPipe.put(processedCoT)
@@ -108,7 +114,7 @@ class SendDataController:
         except Exception as e:
             import traceback
 
-            logger.error('error in send to all ' + str(e)+str(traceback.format_exc()))
+            logger.error('error in send to all ' + str(e)+str(traceback.format_exc()) +" "+ str(clientInformationQueue))
             raise Exception(e)
     def geochat_sending(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
@@ -116,16 +122,16 @@ class SendDataController:
                 return self.send_to_all(clientInformationQueue, processedCoT, sender, shareDataPipe)
     
             else:
-                for client in clientInformationQueue:
+                for client in clientInformationQueue.values():
                     try:
-                        if client.modelObject.uid == processedCoT.modelObject.detail._chat.chatgrp.uid1:
-                            sock = client.socket
+                        if client[1].user_id == processedCoT.modelObject.detail._chat.chatgrp.uid1:
+                            sock = client[0]
                             try:
                                 sock.send(processedCoT.xmlString)
                             except Exception as e:
                                 logger.error('error sending data with marti to client data ' + str(
                                     processedCoT.xmlString) + 'error is ' + str(e))
-                                return (-1, client)
+                                return (-1, client[1])
                         else:
                             continue
                     except Exception as e:
